# Show extra debug messages if option VOLE_CMAKE_DEBUG_OUTPUT is turned on
macro(vole_debug_message)
	if(VOLE_CMAKE_DEBUG_OUTPUT)
		message("${ARGV}")
	endif()
endmacro()

# Check if package was found and set include directories and definitions
macro(vole_check_package package name help_message found includes libraries)
	list(APPEND VOLE_PACKAGE_LIST ${package})
	set(VOLE_PACKAGE_LIST ${VOLE_PACKAGE_LIST} CACHE INTERNAL "Package list" FORCE)

	set(${package}_HELP_MESSAGE "${help_message}")

	if(${found})
		set(${package}_FOUND TRUE)
		set(${package}_INCLUDE_DIRS ${includes})
		set(${package}_LIBRARIES ${libraries})

		set(WITH_${package} TRUE)
		add_definitions(-DWITH_${package})
		include_directories(${includes})

		vole_debug_message("${name} found!")
		vole_debug_message("  ${name} help message: ${help_message}")
		vole_debug_message("  ${name} include directories: ${includes}")
		vole_debug_message("  ${name} libraries: ${libraries}")
		vole_debug_message(" ")
	else()
		vole_debug_message("${name} not found!")
	endif()
endmacro()

# Generate shell configuration
macro(vole_shell_configuration include_header include_command modules)
	set(${include_header})
	set(${include_command})
	set(${modules})

	foreach(module ${VOLE_MODULE_LIST})
		list(GET ${module} 0 module_name)
		list(GET ${module} 1 module_description)
		list(GET ${module} 2 dependencies_found)
		list(GET ${module} 3 module_variable)
		list(GET ${module} 4 required_modules)
		list(GET ${module} 5 required_dependencies)
		list(GET ${module} 6 command_list)
		list(GET ${module} 7 module_ok)

		# FIXME: Check optional module dependencies.
#		if(NOT ${module_name} STREQUAL common)
			set_target_properties(${module_name}-lib PROPERTIES COMPILE_FLAGS "-DGerbil_Common")
#		endif()

		if(${module_variable} AND ${command_list})
			list(APPEND ${modules} ${module_name})

			foreach(command ${${command_list}})
				list(GET ${command} 0 command_name)
				list(GET ${command} 1 command_header)
				list(GET ${command} 2 command_class)

				set(${include_header} "${${include_header}}\n/* ${module_description} */\n#include \"${command_header}\"")
				set(${include_command} "${${include_command}}\n	/* ${module_description} */\n	c = new ${command_class}(); insert(std::make_pair(c->getName(), c));")
			endforeach()
		endif()
	endforeach()
endmacro()
